@@ -377,9 +377,12 @@ unitizer_sect('all_bw - strings', {
   # simple tests with utf8 bookends
 
   all_bw(lorem.ru.phrases, "\t", utf8$e2)
-  all_bw(lorem.ru.phrases, "\t", utf8$s2)
-  all_bw(lorem.cn.phrases, "\t", utf8$e2)
   all_bw(lorem.cn.phrases, "\t", utf8$e3)
+
+  # # these two produce unsupressable warnings on Solaris
+  # all_bw(lorem.ru.phrases, "\t", utf8$s2)
+  # all_bw(lorem.cn.phrases, "\t", utf8$e2)
+
   # Unfortunately something is going wrong with how out-of-BMP unicode is read
   # in by windows so we have to comment out these tests; see #82
   # all_bw(lorem.emo.phrases, "\t", utf8$s4)
